``pyramid_exclog``
===================

A package which logs exception information when an error occurs in your
Pyramid application.  See the documentation at
https://docs.pylonsproject.org/projects/pyramid_exclog/dev/ for more
information.

This package currently will not work with any released Pyramid; it requires
the Pyramid trunk (aka "1.2dev"), available from
https://github.com/Pylons/pyramid .
